@@ -21,10 +21,10 @@ def _is_uvloop_platform() -> bool:
 if _is_uvloop_platform():
     try:
         import uvloop
-    except ImportError:
+    except ImportError:  # pragma: no cover
         pass
 
-__version__ = "3.2.2"
+__version__ = "3.2.4"
 
 install()
 app = Typer()
@@ -90,7 +90,7 @@ def cli(
     if _is_uvloop_platform():
         try:
             uvloop.install()
-        except NameError:
+        except NameError:  # pragma: no cover
             pass
 
     if clear_cache:
